pub struct Json;Expand description
Convert to a JSON string.
Accepts a single argument which is converted to a JSON string and returned.
The optional hash parameter pretty when truthy will pretty print the value.