Lookup

Struct Lookup 

pub struct Lookup;
Lookup a field of an array of object.

Requires exactly two arguments; the first is the target value and the second is a string field name.

If the target field could not be found this helper will return an error.