Enum bracket::render::CallSite[][src]

pub enum CallSite {
    Partial(String),
    Helper(String),
    BlockHelper(String),
}
Call site keeps track of calls so we can detect cyclic calls and therefore prevent a stack overflow by returning a render error when a cycle is detected.

Note that we must distinguish between helper types otherwise the if helper will not work as expected as it returns values and handles block templates.

Variants

Partial(String)

Call site for a partial render.

Tuple Fields of Partial

0: String
Helper(String)

Call site for a helper.

Tuple Fields of Helper

0: String
BlockHelper(String)

Call site for a block helper.

Tuple Fields of BlockHelper

0: String