[−][src]Struct bracket::template::Template
Template that owns the underlying string and a corresponding document node.
Implementations
impl Template[src]
pub fn compile(source: String, options: ParserOptions) -> SyntaxResult<Self>[src]
Compile a new template.
pub fn node(&self) -> &Node<'_>[src]
The document node for the template.
pub fn file_name(&self) -> Option<&str>[src]
Get the file name given when this template was compiled.
pub fn render<'a, T>(
&self,
registry: &'a Registry<'a>,
name: &str,
data: &T,
writer: &'a mut impl Output,
stack: Vec<CallSite>
) -> RenderResult<()> where
T: Serialize, [src]
&self,
registry: &'a Registry<'a>,
name: &str,
data: &T,
writer: &'a mut impl Output,
stack: Vec<CallSite>
) -> RenderResult<()> where
T: Serialize,
Render this template to the given writer.